@@ -31,7 +31,9 @@ if PYQT_VERSIONS == "PyQt5":
         QListView,
         QAction,
         QAbstractScrollArea,
-        QRadioButton
+        QRadioButton,
+        QSpacerItem,
+        QSizePolicy
     )
 
 if PYQT_VERSIONS == "PyQt6":
@@ -66,7 +68,9 @@ if PYQT_VERSIONS == "PyQt6":
         QListView,
         QAction,
         QAbstractScrollArea,
-        QRadioButton
+        QRadioButton,
+        QSpacerItem,
+        QSizePolicy
 )
 
 if PYQT_VERSIONS == "PySide2":
@@ -101,7 +105,9 @@ if PYQT_VERSIONS == "PySide2":
         QListView,
         QAction,
         QAbstractScrollArea,
-        QRadioButton
+        QRadioButton,
+        QSpacerItem,
+        QSizePolicy
     )
 
 if PYQT_VERSIONS == "PySide6":
@@ -136,5 +142,7 @@ if PYQT_VERSIONS == "PySide6":
         QListView,
         QAction,
         QAbstractScrollArea,
-        QRadioButton
+        QRadioButton,
+        QSpacerItem,
+        QSizePolicy
     )
\ No newline at end of file
