@@ -4,8 +4,9 @@ from PyQtGuiLib.header.Qt.qtCore import *
 from PyQtGuiLib.header.py.common import *
 
 from PyQtGuiLib.header.versions import PYQT_VERSIONS
+from PyQtGuiLib.header.utility import is_win_sys, is_mac_sys
 
 
 # 处理mac下无法运行的情况
-if sys.platform == "darwin" and PYQT_VERSIONS in ["PySide2","PySide6"]:
+if is_mac_sys and PYQT_VERSIONS in ["PySide2","PySide6"]:
     os.environ["QT_MAC_WANTS_LAYER"] = "1"
