@@ -23,10 +23,14 @@ class Test(QWidget):
         super().__init__(*args,**kwargs)
         self.resize(800,500)
 
+        self.setWindowOpacity(0.5)
+
+
         self.btn = QPushButton("一号玩家",self)
         self.btn.resize(130,100)
         self.btn.move(200,200)
 
+        # 气泡控件
         self.bu = BubbleWidget(self)
         self.bu.resize(150,100)
         self.bu.setDirection(BubbleWidget.Top)
