@@ -11,7 +11,9 @@ from PyQtGuiLib.header import (
     QThread,
     Signal,
     QColor,
-    QThread
+    QThread,
+    QPushButton,
+    Qt
 )
 
 from PyQtGuiLib.core.widgets import (
@@ -26,7 +28,7 @@ from PyQtGuiLib.core.widgets import (
     继承窗口
 '''
 
-class TestNoBorder(RoundWidget):
+class TestNoBorder(BorderlessWidget):
     def __init__(self,*args,**kwargs):
         super().__init__(*args,**kwargs)
         self.resize(800,500)
@@ -37,8 +39,25 @@ background-color:#d4d4d4;
 border-radius:30px;
 }
         ''')
-        self.setOpacity(0.7)
+        # self.setOpacity(0.7)
 
+        self.flag = False
+
+        self.btn = QPushButton("固定",self)
+        self.btn.move(100,100)
+        self.btn.clicked.connect(self.test)
+
+    def test(self):
+        if self.flag is False:
+            self.btn.setText("解放")
+            self.windowHandle().setFlags(self.windowFlags() | Qt.WindowStaysOnTopHint)
+            self.flag= True
+        else:
+            self.btn.setText("固定")
+            self.windowHandle().setFlags(self.windowFlags() | Qt.Widget)
+            self.flag = False
+        self.show()
+        self.update()
 
 if __name__ == '__main__':
     app = QApplication(sys.argv)
